You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sb...@apache.org on 2014/12/11 14:13:52 UTC

[15/51] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
index c75cb53..6765221 100644
--- a/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
+++ b/modules/core/src/test/java/org/gridgain/grid/GridTestTaskSession.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid;
 
+import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.jetbrains.annotations.*;
@@ -163,31 +164,31 @@ public class GridTestTaskSession implements ComputeTaskSession {
     }
 
     /** {@inheritDoc} */
-    @Override public void saveCheckpoint(String key, Object state) throws GridException {
+    @Override public void saveCheckpoint(String key, Object state) throws IgniteCheckedException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
     @Override public void saveCheckpoint(String key, Object state, ComputeTaskSessionScope scope, long timeout)
-        throws GridException {
+        throws IgniteCheckedException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
     @Override public void saveCheckpoint(String key, Object state, ComputeTaskSessionScope scope, long timeout,
-        boolean overwrite) throws GridException {
+        boolean overwrite) throws IgniteCheckedException {
         assert false : "Not implemented";
     }
 
     /** {@inheritDoc} */
-    @Override public <T> T loadCheckpoint(String key) throws GridException {
+    @Override public <T> T loadCheckpoint(String key) throws IgniteCheckedException {
         assert false : "Not implemented";
 
         return null;
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeCheckpoint(String key) throws GridException {
+    @Override public boolean removeCheckpoint(String key) throws IgniteCheckedException {
         assert false : "Not implemented";
 
         return false;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
index 19e4b9d..f7d933a 100644
--- a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheBalancingStoreSelfTest.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.cache.store;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.*;
@@ -120,7 +120,7 @@ public class GridCacheBalancingStoreSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Integer load(@Nullable GridCacheTx tx, Integer key) throws GridException {
+        @Nullable @Override public Integer load(@Nullable GridCacheTx tx, Integer key) throws IgniteCheckedException {
             boolean res = locks[key].tryLock();
 
             if (res) {
@@ -139,13 +139,13 @@ public class GridCacheBalancingStoreSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public void loadCache(IgniteBiInClosure<Integer, Integer> clo, @Nullable Object... args)
-            throws GridException {
+            throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
         @Override public void loadAll(@Nullable GridCacheTx tx, Collection<? extends Integer> keys,
-            IgniteBiInClosure<Integer, Integer> c) throws GridException {
+            IgniteBiInClosure<Integer, Integer> c) throws IgniteCheckedException {
             for (Integer key : keys) {
                 boolean res = locks[key].tryLock();
 
@@ -163,29 +163,29 @@ public class GridCacheBalancingStoreSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public void put(@Nullable GridCacheTx tx, Integer key, Integer val) throws GridException {
+        @Override public void put(@Nullable GridCacheTx tx, Integer key, Integer val) throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
         @Override public void putAll(@Nullable GridCacheTx tx, Map<? extends Integer, ? extends Integer> map)
-            throws GridException {
+            throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
-        @Override public void remove(@Nullable GridCacheTx tx, Integer key) throws GridException {
+        @Override public void remove(@Nullable GridCacheTx tx, Integer key) throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
         @Override public void removeAll(@Nullable GridCacheTx tx, Collection<? extends Integer> keys)
-            throws GridException {
+            throws IgniteCheckedException {
             // No-op.
         }
 
         /** {@inheritDoc} */
-        @Override public void txEnd(GridCacheTx tx, boolean commit) throws GridException {
+        @Override public void txEnd(GridCacheTx tx, boolean commit) throws IgniteCheckedException {
             // No-op.
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheLoadOnlyStoreAdapterSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheLoadOnlyStoreAdapterSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheLoadOnlyStoreAdapterSelfTest.java
index 9bbde9c..855fdeb 100644
--- a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheLoadOnlyStoreAdapterSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridCacheLoadOnlyStoreAdapterSelfTest.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.cache.store;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.typedef.*;
@@ -59,7 +59,7 @@ public class GridCacheLoadOnlyStoreAdapterSelfTest extends GridCacheAbstractSelf
     private static class TestStore extends GridCacheLoadOnlyStoreAdapter<Integer, String, String> {
         /** {@inheritDoc} */
         @Override protected Iterator<String> inputIterator(@Nullable Object... args)
-            throws GridException {
+            throws IgniteCheckedException {
             assertNotNull(args);
             assertTrue(Arrays.equals(EXP_ARGS, args));
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridGeneratingTestStore.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridGeneratingTestStore.java b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridGeneratingTestStore.java
index ea1ad17..640d46e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/cache/store/GridGeneratingTestStore.java
+++ b/modules/core/src/test/java/org/gridgain/grid/cache/store/GridGeneratingTestStore.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.cache.store;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
@@ -31,13 +31,13 @@ public class GridGeneratingTestStore implements GridCacheStore<String, String> {
 
     /** {@inheritDoc} */
     @Override public String load(@Nullable GridCacheTx tx, String key)
-        throws GridException {
+        throws IgniteCheckedException {
         return null;
     }
 
     /** {@inheritDoc} */
     @Override public void loadCache(IgniteBiInClosure<String, String> clo,
-        @Nullable Object... args) throws GridException {
+        @Nullable Object... args) throws IgniteCheckedException {
         if (args.length > 0) {
             try {
                 int cnt = ((Number)args[0]).intValue();
@@ -49,7 +49,7 @@ public class GridGeneratingTestStore implements GridCacheStore<String, String> {
             catch (Exception e) {
                 X.println("Unexpected exception in loadAll: " + e);
 
-                throw new GridException(e);
+                throw new IgniteCheckedException(e);
             }
         }
         else {
@@ -60,37 +60,37 @@ public class GridGeneratingTestStore implements GridCacheStore<String, String> {
 
     /** {@inheritDoc} */
     @Override public void loadAll(@Nullable GridCacheTx tx,
-        @Nullable Collection<? extends String> keys, IgniteBiInClosure<String, String> c) throws GridException {
+        @Nullable Collection<? extends String> keys, IgniteBiInClosure<String, String> c) throws IgniteCheckedException {
         for (String key : keys)
             c.apply(key, "val" + key);
     }
 
     /** {@inheritDoc} */
     @Override public void put(@Nullable GridCacheTx tx, String key, @Nullable String val)
-        throws GridException {
+        throws IgniteCheckedException {
         // No-op.
     }
 
     /** {@inheritDoc} */
     @Override public void putAll(@Nullable GridCacheTx tx,
-        @Nullable Map<? extends String, ? extends String> map) throws GridException {
+        @Nullable Map<? extends String, ? extends String> map) throws IgniteCheckedException {
         // No-op.
     }
 
     /** {@inheritDoc} */
     @Override public void remove(@Nullable GridCacheTx tx, String key)
-        throws GridException {
+        throws IgniteCheckedException {
         // No-op.
     }
 
     /** {@inheritDoc} */
     @Override public void removeAll(@Nullable GridCacheTx tx,
-        @Nullable Collection<? extends String> keys) throws GridException {
+        @Nullable Collection<? extends String> keys) throws IgniteCheckedException {
         // No-op.
     }
 
     /** {@inheritDoc} */
-    @Override public void txEnd(GridCacheTx tx, boolean commit) throws GridException {
+    @Override public void txEnd(GridCacheTx tx, boolean commit) throws IgniteCheckedException {
         // No-op.
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsEventsAbstractSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsEventsAbstractSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsEventsAbstractSelfTest.java
index fb9e2dd..ada1195 100644
--- a/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsEventsAbstractSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsEventsAbstractSelfTest.java
@@ -79,7 +79,7 @@ public abstract class GridGgfsEventsAbstractSelfTest extends GridCommonAbstractT
     /**
      * @return GGFS configuration for this test.
      */
-    protected IgniteFsConfiguration getGgfsConfiguration() throws GridException {
+    protected IgniteFsConfiguration getGgfsConfiguration() throws IgniteCheckedException {
         IgniteFsConfiguration ggfsCfg = new IgniteFsConfiguration();
 
         ggfsCfg.setDataCacheName("dataCache");
@@ -510,7 +510,7 @@ public abstract class GridGgfsEventsAbstractSelfTest extends GridCommonAbstractT
         try {
             ggfs.delete(dir.parent(), false); // Will generate no events.
         }
-        catch (GridException ignore) {
+        catch (IgniteCheckedException ignore) {
             // No-op.
         }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsPathSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
index a233144..d392ca3 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
@@ -61,7 +61,7 @@ public class GridAlwaysFailoverSpiFailSelfTest extends GridCommonAbstractTest {
 
             assert false;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             //No-op
         }
 
@@ -81,11 +81,11 @@ public class GridAlwaysFailoverSpiFailSelfTest extends GridCommonAbstractTest {
 
         try {
             ignite.compute().execute(GridTestFailoverTask.class.getName(),
-                new GridException("Task should NOT be failed over"));
+                new IgniteCheckedException("Task should NOT be failed over"));
 
             assert false;
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             //No-op
         }
 
@@ -110,19 +110,19 @@ public class GridAlwaysFailoverSpiFailSelfTest extends GridCommonAbstractTest {
         /** {@inheritDoc} */
         @Override public Collection<? extends ComputeJob> split(int gridSize, Object arg) {
             assert gridSize == 1;
-            assert arg instanceof GridException;
+            assert arg instanceof IgniteCheckedException;
 
             Collection<ComputeJob> res = new ArrayList<>(gridSize);
 
             for (int i = 0; i < gridSize; i++)
-                res.add(new GridTestFailoverJob((GridException)arg));
+                res.add(new GridTestFailoverJob((IgniteCheckedException)arg));
 
             return res;
         }
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res,
-            List<ComputeJobResult> received) throws GridException {
+            List<ComputeJobResult> received) throws IgniteCheckedException {
             if (res.getException() != null)
                 return ComputeJobResultPolicy.FAILOVER;
 
@@ -142,11 +142,11 @@ public class GridAlwaysFailoverSpiFailSelfTest extends GridCommonAbstractTest {
         /**
          * @param ex Exception to be thrown in {@link #execute}.
          */
-        GridTestFailoverJob(GridException ex) { super(ex); }
+        GridTestFailoverJob(IgniteCheckedException ex) { super(ex); }
 
         /** {@inheritDoc} */
-        @Override public GridException execute() throws GridException {
-            throw this.<GridException>argument(0);
+        @Override public IgniteCheckedException execute() throws IgniteCheckedException {
+            throw this.<IgniteCheckedException>argument(0);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCacheProjectionRemoveTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
index cf2411e..c20926e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
@@ -65,7 +65,7 @@ public class GridCancelOnGridStopSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable String arg)
-            throws GridException {
+            throws IgniteCheckedException {
             for (ClusterNode node : subgrid) {
                 if (node.id().equals(locId)) {
                     return Collections.singletonMap(new ComputeJob() {
@@ -73,14 +73,14 @@ public class GridCancelOnGridStopSelfTest extends GridCommonAbstractTest {
                             cancelCall = true;
                         }
 
-                        @Override public Serializable execute() throws GridException {
+                        @Override public Serializable execute() throws IgniteCheckedException {
                             cnt.countDown();
 
                             try {
                                 Thread.sleep(Long.MAX_VALUE);
                             }
                             catch (InterruptedException e) {
-                                throw new GridException(e);
+                                throw new IgniteCheckedException(e);
                             }
 
                             return null;
@@ -89,11 +89,11 @@ public class GridCancelOnGridStopSelfTest extends GridCommonAbstractTest {
                 }
             }
 
-            throw new GridException("Local node not found");
+            throw new IgniteCheckedException("Local node not found");
         }
 
         /** {@inheritDoc} */
-        @Nullable @Override public Void reduce(List<ComputeJobResult> results) throws GridException {
+        @Nullable @Override public Void reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
index 8aba9cd..e46813c 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelUnusedJobSelfTest.java
@@ -117,7 +117,7 @@ public class GridCancelUnusedJobSelfTest extends GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             if (log.isInfoEnabled())
                 log.info("Splitting job [job=" + this + ", gridSize=" + gridSize + ", arg=" + arg + ']');
 
@@ -135,7 +135,7 @@ public class GridCancelUnusedJobSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             if (log.isInfoEnabled())
                 log.info("Reducing job [job=" + this + ", results=" + results + ']');
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
index d643e7d..afcf4ac 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelledJobsMetricsSelfTest.java
@@ -86,9 +86,9 @@ public class GridCancelledJobsMetricsSelfTest extends GridCommonAbstractTest {
 
                 assert false : "Job was not interrupted.";
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 if (e.hasCause(InterruptedException.class))
-                    throw new GridException("Test run has been interrupted.", e);
+                    throw new IgniteCheckedException("Test run has been interrupted.", e);
 
                 info("Caught expected exception: " + e.getMessage());
             }
@@ -122,7 +122,7 @@ public class GridCancelledJobsMetricsSelfTest extends GridCommonAbstractTest {
      */
     private static final class GridCancelledJob extends ComputeJobAdapter {
         /** {@inheritDoc} */
-        @Override public String execute() throws GridException {
+        @Override public String execute() throws IgniteCheckedException {
             X.println("Executing job.");
 
             try {
@@ -133,10 +133,10 @@ public class GridCancelledJobsMetricsSelfTest extends GridCommonAbstractTest {
                     Thread.sleep(1000);
                 }
                 catch (InterruptedException e1) {
-                    throw new GridException("Unexpected exception: ", e1);
+                    throw new IgniteCheckedException("Unexpected exception: ", e1);
                 }
 
-                throw new GridException("Job got interrupted while waiting for cancellation.");
+                throw new IgniteCheckedException("Job got interrupted while waiting for cancellation.");
             }
             finally {
                 X.println("Finished job.");

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCommunicationSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCommunicationSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCommunicationSelfTest.java
index 17271e8..a8caced 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCommunicationSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCommunicationSelfTest.java
@@ -59,7 +59,7 @@ public class GridCommunicationSelfTest extends GridCommonAbstractTest {
             message(ignite.cluster().forNodes(nodes)).send(null,
                 new GridTestCommunicationMessage(cntr, ignite.cluster().localNode().id()));
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             error("Failed to send message.", e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
index 0329ad0..65c1a0e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobAnnotationSelfTest.java
@@ -97,12 +97,12 @@ public class GridContinuousJobAnnotationSelfTest extends GridCommonAbstractTest
         private ComputeTaskContinuousMapper mapper;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             try {
                 mapper.send(((Class<ComputeJob>)arg).newInstance());
             }
             catch (Exception e) {
-                throw new GridException("Job instantination failed.", e);
+                throw new IgniteCheckedException("Job instantination failed.", e);
             }
 
             return null;
@@ -110,10 +110,10 @@ public class GridContinuousJobAnnotationSelfTest extends GridCommonAbstractTest
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received)
-            throws GridException {
+            throws IgniteCheckedException {
             if (res.getException() != null) {
                 if (res.getException() instanceof ComputeUserUndeclaredException)
-                    throw new GridException("Job threw unexpected exception.", res.getException());
+                    throw new IgniteCheckedException("Job threw unexpected exception.", res.getException());
 
                 return ComputeJobResultPolicy.FAILOVER;
             }
@@ -122,7 +122,7 @@ public class GridContinuousJobAnnotationSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 1 : "Unexpected result count: " + results.size();
 
             return null;
@@ -171,7 +171,7 @@ public class GridContinuousJobAnnotationSelfTest extends GridCommonAbstractTest
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws GridException {
+        @Override public Serializable execute() throws IgniteCheckedException {
             X.println("Execute TestJob [this=" + this + ", identity=" + System.identityHashCode(this) +
                 ", flag=" + flag + "]");
 
@@ -187,7 +187,7 @@ public class GridContinuousJobAnnotationSelfTest extends GridCommonAbstractTest
             if (fail.get()) {
                 fail.set(false);
 
-                throw new GridException("Expected test exception.");
+                throw new IgniteCheckedException("Expected test exception.");
             }
 
             return null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
index bf7cd1f..9d27620 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousJobSiblingsSelfTest.java
@@ -69,15 +69,15 @@ public class GridContinuousJobSiblingsSelfTest extends GridCommonAbstractTest {
         private volatile int jobCnt;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton(new TestJob(++jobCnt));
         }
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received)
-            throws GridException {
+            throws IgniteCheckedException {
             if (res.getException() != null)
-                throw new GridException("Job resulted in error: " + res, res.getException());
+                throw new IgniteCheckedException("Job resulted in error: " + res, res.getException());
 
             assert ses.getJobSiblings().size() == jobCnt;
 
@@ -91,7 +91,7 @@ public class GridContinuousJobSiblingsSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assertEquals(JOB_COUNT, results.size());
 
             return null;
@@ -116,7 +116,7 @@ public class GridContinuousJobSiblingsSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws GridException {
+        @Override public Serializable execute() throws IgniteCheckedException {
             assert ses != null;
             assert argument(0) != null;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
index 1cd05ec..15ca5ff 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridContinuousTaskSelfTest.java
@@ -81,7 +81,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
                         assert fut1.get() == 55;
                         assert fut2.get() == 55;
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         assert false : "Test task failed: " + e;
                     }
                 }
@@ -142,7 +142,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         private int cnt;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Boolean arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Boolean arg) throws IgniteCheckedException {
             assert mapper != null;
             assert arg != null;
 
@@ -163,7 +163,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received) throws GridException {
+        @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received) throws IgniteCheckedException {
             assert mapper != null;
             assert res.getException() == null : "Unexpected exception: " + res.getException();
 
@@ -181,7 +181,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 10 : "Unexpected result count: " + results.size();
 
             log.info("Called reduce() method [results=" + results + ']');
@@ -212,7 +212,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws GridException {
+        @Override public Serializable execute() throws IgniteCheckedException {
             Integer i = argument(0);
 
             return i != null ? i : 0;
@@ -236,7 +236,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             ses.addAttributeListener(new ComputeTaskSessionAttributeListener() {
                 @Override public void onAttributeSet(Object key, Object val) {
                     if (key instanceof String) {
@@ -249,7 +249,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
                                 try {
                                     mapper.send(new SessionChainTestJob(cnt));
                                 }
-                                catch (GridException e) {
+                                catch (IgniteCheckedException e) {
                                     log.error("Failed to send new job.", e);
                                 }
                             }
@@ -267,7 +267,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assertEquals(JOB_COUNT * JOB_COUNT, results.size());
 
             return null;
@@ -296,7 +296,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws GridException {
+        @Override public Serializable execute() throws IgniteCheckedException {
             Integer i = argument(0);
 
             int arg = i != null ? i : 0;
@@ -318,14 +318,14 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         private int cnt;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             mapper.send(new TestJob(++cnt));
 
             try {
                 Thread.sleep(10000);
             }
             catch (InterruptedException e) {
-                throw new GridException("Job has been interrupted.", e);
+                throw new IgniteCheckedException("Job has been interrupted.", e);
             }
 
             mapper.send(new TestJob(++cnt));
@@ -334,7 +334,7 @@ public class GridContinuousTaskSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return results == null ? 0 : results.size();
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
index 81bd5d3..012a833 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentMultiThreadedSelfTest.java
@@ -57,7 +57,7 @@ public class GridDeploymentMultiThreadedSelfTest extends GridCommonAbstractTest
                         if (++iterCnt % 100 == 0)
                             info("Iterations count: " + iterCnt);
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         U.error(log, "Failed to undeploy task message.", e);
 
                         fail("See logs for details.");
@@ -100,14 +100,14 @@ public class GridDeploymentMultiThreadedSelfTest extends GridCommonAbstractTest
      */
     private static class GridDeploymentTestTask extends ComputeTaskAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             assert false;
 
             return Collections.emptyMap();
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
index 712734c..33858b1 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDeploymentSelfTest.java
@@ -217,7 +217,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
 
                 assert false : "Should not be able to deploy 2 task with same task name";
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 info("Received expected grid exception: " + e);
             }
 
@@ -355,7 +355,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg)
-            throws GridException {
+            throws IgniteCheckedException {
             Map<ComputeJobAdapter, ClusterNode> map = new HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -373,7 +373,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }
@@ -388,7 +388,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             Map<ComputeJobAdapter, ClusterNode> map = new HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -405,7 +405,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }
@@ -420,7 +420,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, Object arg) throws IgniteCheckedException {
             Map<ComputeJobAdapter, ClusterNode> map = new HashMap<>(subgrid.size());
 
             for (ClusterNode node : subgrid) {
@@ -438,7 +438,7 @@ public class GridDeploymentSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDiscoveryEventSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDiscoveryEventSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDiscoveryEventSelfTest.java
index d5f0e49..205e0b0 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridDiscoveryEventSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridDiscoveryEventSelfTest.java
@@ -375,7 +375,7 @@ public class GridDiscoveryEventSelfTest extends GridCommonAbstractTest {
         try {
             startGridsMultiThreaded(3);
 
-            final AtomicReference<GridException> err = new AtomicReference<>();
+            final AtomicReference<IgniteCheckedException> err = new AtomicReference<>();
 
             for (int i = 0; i < 3; i++) {
                 Ignite g = grid(i);
@@ -385,7 +385,7 @@ public class GridDiscoveryEventSelfTest extends GridCommonAbstractTest {
                         IgniteDiscoveryEvent discoEvt = (IgniteDiscoveryEvent) evt;
 
                         if (discoEvt.topologyNodes().size() != 3)
-                            err.compareAndSet(null, new GridException("Invalid discovery event [evt=" + discoEvt +
+                            err.compareAndSet(null, new IgniteCheckedException("Invalid discovery event [evt=" + discoEvt +
                                 ", nodes=" + discoEvt.topologyNodes() + ']'));
 
                         return true;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
index 7058d66..0c0fa14 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageCheckAllEventsSelfTest.java
@@ -154,7 +154,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
 
             assert false : "Grid with locally executed job with timeout should throw GridComputeTaskTimeoutException.";
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             info("Expected exception caught [taskFuture=" + fut + ", exception=" + e + ']');
         }
 
@@ -340,7 +340,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
         private ComputeTaskSession taskSes;
 
         /** {@inheritDoc} */
-        @Override public String execute() throws GridException {
+        @Override public String execute() throws IgniteCheckedException {
             assert taskSes != null;
 
             taskSes.saveCheckpoint("testCheckpoint", "TestState");
@@ -394,7 +394,7 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
         private ComputeTaskSession taskSes;
 
         /** {@inheritDoc} */
-        @Override public String execute() throws GridException {
+        @Override public String execute() throws IgniteCheckedException {
             assert taskSes != null;
 
             taskSes.saveCheckpoint("testAllCheckpoint", "CheckpointTestState");
@@ -411,12 +411,12 @@ public class GridEventStorageCheckAllEventsSelfTest extends GridCommonAbstractTe
     @ComputeTaskSessionFullSupport
     private static class GridAllEventsTestTask extends ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton((ComputeJob)arg);
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results != null;
             assert results.size() == 1;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageRuntimeConfigurationSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageRuntimeConfigurationSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageRuntimeConfigurationSelfTest.java
index 0fda221..bcc2d5e 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageRuntimeConfigurationSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageRuntimeConfigurationSelfTest.java
@@ -181,7 +181,7 @@ public class GridEventStorageRuntimeConfigurationSelfTest extends GridCommonAbst
             try {
                 g.events().isEnabled(-13);
 
-                fail("Expected GridException");
+                fail("Expected IgniteCheckedException");
             }
             catch (IllegalArgumentException e) {
                 info("Caught expected exception: " + e);
@@ -194,9 +194,9 @@ public class GridEventStorageRuntimeConfigurationSelfTest extends GridCommonAbst
         inclEvtTypes = new int[]{-13};
 
         try (Ignite g = startGrid()) {
-            fail("Expected GridException");
+            fail("Expected IgniteCheckedException");
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             info("Caught expected exception: " + e);
         }
         finally {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
index efbcd30..4b5a5fa 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
@@ -395,7 +395,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends GridCommonAbstractTe
         private UUID locId;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
             Map<ComputeJobAdapter, ClusterNode> map = new HashMap<>(subgrid.size());
 
             boolean ignoreLocNode = false;
@@ -417,7 +417,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends GridCommonAbstractTe
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return results.get(0).getData();
         }
     }
@@ -432,7 +432,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends GridCommonAbstractTe
         private IgniteLogger log;
 
         /** {@inheritDoc} */
-        @Override public Serializable execute() throws GridException {
+        @Override public Serializable execute() throws IgniteCheckedException {
             if (log.isInfoEnabled())
                 log.info("Executing grid job: " + this);
 
@@ -460,7 +460,7 @@ public class GridExplicitImplicitDeploymentSelfTest extends GridCommonAbstractTe
                 return null;
             }
             catch (IOException e) {
-                throw new GridException("Failed to execute job.", e);
+                throw new IgniteCheckedException("Failed to execute job.", e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFactoryVmShutdownTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFactoryVmShutdownTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFactoryVmShutdownTest.java
index 6409886..37aa005 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFactoryVmShutdownTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFactoryVmShutdownTest.java
@@ -70,8 +70,8 @@ public class GridFactoryVmShutdownTest {
                 try {
                     G.start(cfg);
                 }
-                catch (GridException e) {
-                    throw new GridRuntimeException("Failed to start grid in shutdown hook.", e);
+                catch (IgniteCheckedException e) {
+                    throw new IgniteException("Failed to start grid in shutdown hook.", e);
                 }
                 finally {
                     X.println("States: " + states);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
index a70907b..c695b84 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverCustomTopologySelfTest.java
@@ -92,7 +92,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
 
                 info("Task result: " + res);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 info("Got unexpected grid exception: " + e);
             }
 
@@ -120,7 +120,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
         private UUID locNodeId;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
             assert locNodeId != null;
 
             if (log.isInfoEnabled())
@@ -140,7 +140,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
 
                 /** {@inheritDoc} */
                 @SuppressWarnings("NakedNotify")
-                @Override public Serializable execute() throws GridException {
+                @Override public Serializable execute() throws IgniteCheckedException {
                     assert nodeId != null;
 
                     if (!nodeId.equals(argument(0))) {
@@ -164,7 +164,7 @@ public class GridFailoverCustomTopologySelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public String reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public String reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 1;
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
index 9a5c38f..b0fba9b 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverSelfTest.java
@@ -76,7 +76,7 @@ public class GridFailoverSelfTest extends GridCommonAbstractTest {
         private ComputeTaskSession ses;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
             ses.setAttribute("fail", true);
 
             nodeRef.set(subgrid.get(0));
@@ -87,14 +87,14 @@ public class GridFailoverSelfTest extends GridCommonAbstractTest {
                 private UUID locId;
 
                 /** {@inheritDoc} */
-                @Override public Serializable execute() throws GridException {
+                @Override public Serializable execute() throws IgniteCheckedException {
                     boolean fail;
 
                     try {
                         fail = ses.<String, Boolean>waitForAttribute("fail", 0);
                     }
                     catch (InterruptedException e) {
-                        throw new GridException("Got interrupted while waiting for attribute to be set.", e);
+                        throw new IgniteCheckedException("Got interrupted while waiting for attribute to be set.", e);
                     }
 
                     if (fail) {
@@ -102,7 +102,7 @@ public class GridFailoverSelfTest extends GridCommonAbstractTest {
 
                         assert nodeRef.get().id().equals(locId);
 
-                        throw new GridException("Job exception.");
+                        throw new IgniteCheckedException("Job exception.");
                     }
 
                     assert !nodeRef.get().id().equals(locId);
@@ -115,7 +115,7 @@ public class GridFailoverSelfTest extends GridCommonAbstractTest {
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res,
-            List<ComputeJobResult> received) throws GridException {
+            List<ComputeJobResult> received) throws IgniteCheckedException {
             if (res.getException() != null && !(res.getException() instanceof ComputeUserUndeclaredException)) {
                 assert res.getNode().id().equals(nodeRef.get().id());
 
@@ -128,7 +128,7 @@ public class GridFailoverSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 1;
 
             assert nodeRef.get() != null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
index 4658fa1..893b213 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTaskWithPredicateSelfTest.java
@@ -186,7 +186,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends GridCommonAbstractTes
         private ComputeTaskSession ses;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
             ses.setAttribute("fail", true);
 
             return Collections.singletonMap(new ComputeJobAdapter(arg) {
@@ -197,20 +197,20 @@ public class GridFailoverTaskWithPredicateSelfTest extends GridCommonAbstractTes
                 /** {@inheritDoc} */
                 @SuppressWarnings({"RedundantTypeArguments"})
                 @Override
-                public Serializable execute() throws GridException {
+                public Serializable execute() throws IgniteCheckedException {
                     boolean fail;
 
                     try {
                         fail = ses.<String, Boolean>waitForAttribute("fail", 0);
                     }
                     catch (InterruptedException e) {
-                        throw new GridException("Got interrupted while waiting for attribute to be set.", e);
+                        throw new IgniteCheckedException("Got interrupted while waiting for attribute to be set.", e);
                     }
 
                     if (fail) {
                         ses.setAttribute("fail", false);
 
-                        throw new GridException("Job exception.");
+                        throw new IgniteCheckedException("Job exception.");
                     }
 
                     // This job does not return any result.
@@ -221,7 +221,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends GridCommonAbstractTes
 
         /** {@inheritDoc} */
         @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received)
-                throws GridException {
+                throws IgniteCheckedException {
             if (res.getException() != null && !(res.getException() instanceof ComputeUserUndeclaredException))
                 return ComputeJobResultPolicy.FAILOVER;
 
@@ -229,7 +229,7 @@ public class GridFailoverTaskWithPredicateSelfTest extends GridCommonAbstractTes
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 1;
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
index e04990e..d704f03 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridFailoverTopologySelfTest.java
@@ -87,7 +87,7 @@ public class GridFailoverTopologySelfTest extends GridCommonAbstractTest {
             try {
                 compute(ignite1.cluster().forRemotes()).execute(JobFailTask.class, null);
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 info("Got expected grid exception: " + e);
             }
 
@@ -109,7 +109,7 @@ public class GridFailoverTopologySelfTest extends GridCommonAbstractTest {
         private boolean jobFailedOver;
 
         /** {@inheritDoc} */
-        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws GridException {
+        @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, String arg) throws IgniteCheckedException {
             assert locNodeId != null;
 
             ClusterNode remoteNode = null;
@@ -120,14 +120,14 @@ public class GridFailoverTopologySelfTest extends GridCommonAbstractTest {
             }
 
             return Collections.singletonMap(new ComputeJobAdapter(arg) {
-                @Override public Serializable execute() throws GridException {
-                    throw new GridException("Job exception.");
+                @Override public Serializable execute() throws IgniteCheckedException {
+                    throw new IgniteCheckedException("Job exception.");
                 }
             }, remoteNode);
         }
 
         /** {@inheritDoc} */
-        @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received) throws GridException {
+        @Override public ComputeJobResultPolicy result(ComputeJobResult res, List<ComputeJobResult> received) throws IgniteCheckedException {
             if (res.getException() != null && !jobFailedOver) {
                 jobFailedOver = true;
 
@@ -138,7 +138,7 @@ public class GridFailoverTopologySelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results.size() == 1;
 
             return results.get(0).getData();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridHomePathSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridHomePathSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridHomePathSelfTest.java
index 1ae3145..a80a1df 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridHomePathSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridHomePathSelfTest.java
@@ -8,8 +8,8 @@
  */
 package org.gridgain.grid.kernal;
 
+import org.apache.ignite.*;
 import org.apache.ignite.configuration.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.testframework.junits.common.*;
 
@@ -46,7 +46,7 @@ public class GridHomePathSelfTest extends GridCommonAbstractTest {
                 assert false : "Exception should have been thrown.";
             }
             catch (Exception e) {
-                if (X.hasCause(e, GridRuntimeException.class))
+                if (X.hasCause(e, IgniteException.class))
                     info("Caught expected exception: " + e);
                 else
                     throw e;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
index a290a2c..ac2c46f 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCheckpointCleanupSelfTest.java
@@ -119,14 +119,14 @@ public class GridJobCheckpointCleanupSelfTest extends GridCommonAbstractTest {
     private static class CheckpointCountingTestTask extends ComputeTaskAdapter<ClusterNode, Object> {
         /** {@inheritDoc} */
         @Override public Map<? extends ComputeJob, ClusterNode> map(List<ClusterNode> subgrid, @Nullable ClusterNode arg)
-            throws GridException {
+            throws IgniteCheckedException {
             for (ClusterNode node : subgrid) {
                 if (node.id().equals(arg.id()))
                     return Collections.singletonMap(new ComputeJobAdapter() {
                         @IgniteTaskSessionResource
                         private ComputeTaskSession ses;
 
-                        @Nullable @Override public Object execute() throws GridException {
+                        @Nullable @Override public Object execute() throws IgniteCheckedException {
                             ses.saveCheckpoint("checkpoint-key", "checkpoint-value");
 
                             return null;
@@ -141,7 +141,7 @@ public class GridJobCheckpointCleanupSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
index b141ebe..5f646cd 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobCollisionCancelSelfTest.java
@@ -88,7 +88,7 @@ public class GridJobCollisionCancelSelfTest extends GridCommonAbstractTest {
         catch (Exception e) {
             assert e.getCause() != null;
 
-            if (e.getCause() instanceof GridException)
+            if (e.getCause() instanceof IgniteCheckedException)
                 e = (Exception)e.getCause();
 
             if (e.getCause() instanceof IOException)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobContextSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobContextSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobContextSelfTest.java
index 7c26f77..82d4961 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobContextSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobContextSelfTest.java
@@ -47,7 +47,7 @@ public class GridJobContextSelfTest extends GridCommonAbstractTest {
     /** */
     @SuppressWarnings("PublicInnerClass")
     public static class JobContextTask extends ComputeTaskSplitAdapter<Object, Object> {
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>(gridSize);
 
             for (int i = 0; i < gridSize; i++) {
@@ -89,7 +89,7 @@ public class GridJobContextSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Object reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             for (ComputeJobResult res : results) {
                 ComputeJobContext jobCtx = res.getJobContext();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
index a7b34a1..6aae0f6 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridJobMasterLeaveAwareSelfTest.java
@@ -248,7 +248,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testApply1() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(), "arg");
@@ -263,7 +263,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testApply2() throws Exception {
         testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(), Arrays.asList("arg1", "arg2"));
@@ -278,7 +278,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testApply3() throws Exception {
         testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup grid) throws IgniteCheckedException {
                 IgniteCompute comp = compute(grid).enableAsync();
 
                 comp.apply(new TestClosure(),
@@ -303,7 +303,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testRun1() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.run(new TestRunnable());
@@ -318,7 +318,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testRun2() throws Exception {
         testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.run(Arrays.asList(new TestRunnable(), new TestRunnable()));
@@ -333,7 +333,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testCall1() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(new TestCallable());
@@ -348,7 +348,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testCall2() throws Exception {
         testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(Arrays.asList(new TestCallable(), new TestCallable()));
@@ -363,7 +363,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testCall3() throws Exception {
         testMasterLeaveAwareCallback(2, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.call(
@@ -388,7 +388,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testBroadcast1() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestRunnable());
@@ -403,7 +403,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testBroadcast2() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestCallable());
@@ -418,7 +418,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testBroadcast3() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 comp.broadcast(new TestClosure(), "arg");
@@ -433,7 +433,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testAffinityRun() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 GridCacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -452,7 +452,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
      */
     public void testAffinityCall() throws Exception {
         testMasterLeaveAwareCallback(1, new CX1<ClusterGroup, IgniteFuture<?>>() {
-            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws GridException {
+            @Override public IgniteFuture<?> applyx(ClusterGroup prj) throws IgniteCheckedException {
                 IgniteCompute comp = compute(prj).enableAsync();
 
                 GridCacheAffinity<Object> aff = prj.ignite().cache(null).affinity();
@@ -517,7 +517,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         try {
             fut.get();
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             log.debug("Task failed: " + e);
         }
     }
@@ -592,7 +592,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
             masterLeaveAware.onMasterLeave(log, this);
         }
     }
@@ -614,7 +614,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
             masterLeaveAware.onMasterLeave(log, this);
         }
     }
@@ -638,7 +638,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
             masterLeaveAware.onMasterLeave(log, this);
         }
     }
@@ -664,7 +664,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, String arg) throws IgniteCheckedException {
             Collection<ComputeJobAdapter> jobs = new ArrayList<>(jobCnt);
 
             for (int i = 0; i < jobCnt; i++)
@@ -674,7 +674,7 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Integer reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Integer reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             return null;
         }
     }
@@ -698,14 +698,14 @@ public class GridJobMasterLeaveAwareSelfTest extends GridCommonAbstractTest {
         }
 
         /** {@inheritDoc} */
-        @Override public Object execute() throws GridException {
+        @Override public Object execute() throws IgniteCheckedException {
             masterLeaveAware.execute(log);
 
             return null;
         }
 
         /** {@inheritDoc} */
-        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws GridException {
+        @Override public void onMasterNodeLeft(ComputeTaskSession ses) throws IgniteCheckedException {
             masterLeaveAware.onMasterLeave(log, this);
         }
     }
diff --git a/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsPathSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsPathSelfTest.java
index 8e25e29..4085084 100644
--- a/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsPathSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/ggfs/GridGgfsPathSelfTest.java
@@ -9,10 +9,10 @@
 
 package org.gridgain.grid.ggfs;
 
+import org.apache.ignite.*;
 import org.apache.ignite.fs.*;
 import org.apache.ignite.marshaller.*;
 import org.apache.ignite.marshaller.optimized.*;
-import org.gridgain.grid.*;
 import org.gridgain.testframework.*;
 import org.gridgain.testframework.junits.common.*;
 import org.jetbrains.annotations.*;
@@ -73,9 +73,9 @@ public class GridGgfsPathSelfTest extends GridCommonAbstractTest {
      *
      * @param obj Object to marshal/unmarshal.
      * @return Marshalled and then unmarshalled object.
      * @throws GridException In case of any marshalling exception.
      */
-    private <T> T mu(T obj) throws GridException {
+    private <T> T mu(T obj) throws IgniteCheckedException {
         return marshaller.unmarshal(marshaller.marshal(obj), null);
     }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinityMappedTest.java
----------------------------------------------------------------------
@@ -73,9 +73,9 @@ public class GridGgfsPathSelfTest extends GridCommonAbstractTest {
      * @param obj Object to marshal/unmarshal.
      * @return Marshalled and then unmarshalled object.
-     * @throws GridException In case of any marshalling exception.
+     * @throws IgniteCheckedException In case of any marshalling exception.
      */
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinityMappedTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinityMappedTest.java
index 1c914d4..85848ce 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinityMappedTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinityMappedTest.java
@@ -82,9 +82,9 @@ public class GridAffinityMappedTest extends GridCommonAbstractTest {
     }
 
     /**
      * @throws GridException If failed.
      */
-    public void testMappedAffinity() throws GridException {
+    public void testMappedAffinity() throws IgniteCheckedException {
         Ignite g1 = grid(1);
         Ignite g2 = grid(2);
         Ignite g3 = grid(3);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinitySelfTest.java
----------------------------------------------------------------------
@@ -82,9 +82,9 @@ public class GridAffinityMappedTest extends GridCommonAbstractTest {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinitySelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinitySelfTest.java
index a0c5b67..09ae000 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinitySelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAffinitySelfTest.java
@@ -71,9 +71,9 @@ public class GridAffinitySelfTest extends GridCommonAbstractTest {
     }
 
     /**
      * @throws GridException If failed.
      */
-    public void testAffinity() throws GridException {
+    public void testAffinity() throws IgniteCheckedException {
         Ignite g1 = grid(1);
         Ignite g2 = grid(2);
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridAlwaysFailoverSpiFailSelfTest.java
----------------------------------------------------------------------
@@ -71,9 +71,9 @@ public class GridAffinitySelfTest extends GridCommonAbstractTest {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCacheProjectionRemoveTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCacheProjectionRemoveTest.java
index 86edaf4..122f2a4 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridCacheProjectionRemoveTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCacheProjectionRemoveTest.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 
 /**
@@ -22,9 +22,9 @@ public class GridCacheProjectionRemoveTest extends GridCacheAbstractSelfTest {
     }
 
     /**
      * @throws GridException If failed.
      */
-    public void testRemove() throws GridException {
+    public void testRemove() throws IgniteCheckedException {
         cache().put("key", 1);
 
         assert cache().remove("key", 1);

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridCancelOnGridStopSelfTest.java
----------------------------------------------------------------------
@@ -22,9 +22,9 @@ public class GridCacheProjectionRemoveTest extends GridCacheAbstractSelfTest {
 
     /**
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
index 531b462..1b96031 100644
--- a/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
+++ b/modules/core/src/test/java/org/gridgain/grid/kernal/GridEventStorageSelfTest.java
@@ -179,9 +179,9 @@ public class GridEventStorageSelfTest extends GridCommonAbstractTest {
      * Create events in grid.
      *
      * @param ignite Grid.
      * @throws GridException In case of error.
      */
-    private void generateEvents(Ignite ignite) throws GridException {
+    private void generateEvents(Ignite ignite) throws IgniteCheckedException {
         ignite.compute().localDeployTask(GridEventTestTask.class, GridEventTestTask.class.getClassLoader());
 
         ignite.compute().execute(GridEventTestTask.class.getName(), null);
@@ -192,12 +192,12 @@ public class GridEventStorageSelfTest extends GridCommonAbstractTest {
      */
     private static class GridEventTestTask extends ComputeTaskSplitAdapter<Object, Object> {
         /** {@inheritDoc} */
-        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws GridException {
+        @Override protected Collection<? extends ComputeJob> split(int gridSize, Object arg) throws IgniteCheckedException {
             return Collections.singleton(new GridEventTestJob());
         }
 
         /** {@inheritDoc} */
-        @Override public Serializable reduce(List<ComputeJobResult> results) throws GridException {
+        @Override public Serializable reduce(List<ComputeJobResult> results) throws IgniteCheckedException {
             assert results != null;
             assert results.size() == 1;
 
@@ -210,7 +210,7 @@ public class GridEventStorageSelfTest extends GridCommonAbstractTest {
      */
     private static class GridEventTestJob extends ComputeJobAdapter {
         /** {@inheritDoc} */
-        @Override public String execute() throws GridException {
+        @Override public String execute() throws IgniteCheckedException {
             return "GridEventTestJob-test-event.";
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/test/java/org/gridgain/grid/kernal/GridExplicitImplicitDeploymentSelfTest.java
----------------------------------------------------------------------
@@ -179,9 +179,9 @@ public class GridEventStorageSelfTest extends GridCommonAbstractTest {
      *
      * @param ignite Grid.
-     * @throws GridException In case of error.
+     * @throws IgniteCheckedException In case of error.
      */